<?php
/*
Plugin Name: WordPress Plus Points
Plugin URI: http://www.dingobytes.com/wordpress/wp-pluspoints/
Description: A handy way to log your meals
Version: 1.0
Author: Andrew Alba
Author URI: http://www.dingobytes.com/

        Credits & Thanks: http://http://www.weightwatchers.com/

*/
define('WPPP_vNum', '1.0');

// Check for location modifications in wp-config
// Then define accordingly
if ( !defined('WP_CONTENT_URL') ) {
	define('WPPP_PLUGPATH',get_option('siteurl').'/wp-content/plugins/'.plugin_basename(dirname(__FILE__)).'/');
	define('WPPP_PLUGDIR', ABSPATH.'/wp-content/plugins/'.plugin_basename(dirname(__FILE__)).'/');
} else {
	define('WPPP_PLUGPATH',WP_CONTENT_URL.'/plugins/'.plugin_basename(dirname(__FILE__)).'/');
	define('WPPP_PLUGDIR',WP_CONTENT_DIR.'/plugins/'.plugin_basename(dirname(__FILE__)).'/');
}

// contains functions for calculations
require_once 'wp-pluspoints.class.php';

function wp_pluspoints_func($atts) {
	global $WP_PlusPoints;
	extract(shortcode_atts(array(
		'servings' => 1,
		'protein' => 0,
		'carbs' => 0,
		'fat' => 0,
		'fiber' => 0,		
	), $atts));
	return $WP_PlusPoints->getPoints($servings,$protein,$carbs,$fat,$fiber);
}

function wp_pluspoints_total_func($atts) {
	global $WP_PlusPoints;
	global $wppp_daily_points;
	extract(shortcode_atts(array(
		'daily_total' => get_option('wppp_daily_points'),		
	), $atts));
	return $WP_PlusPoints->getPostWPPPTotals($daily_total);
}

add_shortcode('wppp', 'wp_pluspoints_func');
add_shortcode('wppp_total', 'wp_pluspoints_total_func');
/* Assigning hooks to actions */
$WP_PlusPoints =& new WP_PlusPoints();

wp_register_style('WPPP-CSS', WPPP_PLUGPATH . 'wppp.css');
wp_enqueue_style('WPPP-CSS');
wp_enqueue_script('WPPP-JS', WPPP_PLUGPATH . 'wppp.js', array('jquery'), '0.1');

// create custom plugin settings menu
add_action('admin_menu', 'wppp_create_menu');

function wppp_create_menu() {
	//create new top-level menu
	add_options_page('WordPress Plus Points Plugin Settings', 'WP Plus Points', 'administrator', __FILE__, 'wppp_settings_page');
	//call register settings function
	add_action( 'admin_init', 'register_wppp_settings' );
}

//setup warning
function wppp_admin_warnings() {
	global $wppp_daily_points;
	if ( !get_option('wppp_daily_points') && !isset($_POST['submit']) ) {
		function wppp_warning() {
			echo "
			<div id='wppp-warning' class='updated fade'><p><strong>".__('WordPress PlusPoints plug-in is almost ready.', 'wp_pluspoints')."</strong> ".sprintf(__('You must <a href="%1$s">enter your personal information</a> for it to work.', 'wp_pluspoints'), "options-general.php?page=wp-pluspoints/wp-pluspoints.php")."</p></div>
			";
		}
		add_action('admin_notices', 'wppp_warning');
		return;
	} 
}

function wppp_warning_init() {
	wppp_admin_warnings();
}
add_action('init', 'wppp_warning_init');

function admin_register_head() {
    echo '<link rel="stylesheet" type="text/css" href="'.WPPP_PLUGPATH. 'wppp_admin.css" />';
}
add_action('admin_head', 'admin_register_head');

function register_wppp_settings() {
	//register our settings
	register_setting('wppp-settings-group', 'wppp_daily_points');
	register_setting('wppp-settings-group', 'wppp_sex');
	register_setting('wppp-settings-group', 'wppp_age');
	register_setting('wppp-settings-group', 'wppp_unit_of_measurement');
	register_setting('wppp-settings-group', 'wppp_weight');
	register_setting('wppp-settings-group', 'wppp_height');
	register_setting('wppp-settings-group', 'wppp_credits');
}

function wppp_settings_page() {
?>
<div class="wrap">
	<div id="icon-options-general" class="icon32 "></div>
	<h2>WordPress Plus Points Personal Settings</h2>
	<script type="text/javascript" charset="utf-8">
	jQuery(function(){
		if(jQuery('input[name=wppp_daily_points]').val() === '') {
			jQuery('input[name=wppp_daily_points]').parent().hide();
		}
		jQuery('input[name=wppp_unit_of_measurement]').change(function() {
			if(jQuery('input[name=wppp_unit_of_measurement]:checked').val() == 'metric') {
				jQuery('input[name=wppp_weight]').val('').next('span').text(' kilograms');
				jQuery('input[name=wppp_height]').val('').next('span').text(' meters');
			}
			else if(jQuery('input[name=wppp_unit_of_measurement]:checked').val() == 'english') {
				jQuery('input[name=wppp_weight]').val('').next('span').text(' pounds');
				jQuery('input[name=wppp_height]').val('').next('span').text(' inches');
			}
		});
		//Validate the form before sending
		jQuery('input[type=submit]').click(function() {
			var errorMessage=[], elFocus, tee, atee, targetPoints, sex, age, unit, weight, height;
			var intCheck = /^\d+$/;
			var floatCheck = /[0-9\.]/;
			if(jQuery('input[name=wppp_sex]:checked').length < 1){
				errorMessage.push("Please select a sex");
				if( typeof(elFocus) == 'undefined' )
				{
					elFocus=jQuery('input[name=wppp_sex]');
				}
			}
			if(jQuery('input[name=wppp_age]').val() === '' || (jQuery('input[name=wppp_age]').val() !== '' && !intCheck.test(jQuery('input[name=wppp_age]').val()))) {
				errorMessage.push("Please enter an integer for your age");
				if( typeof(elFocus) == 'undefined' )
				{
					elFocus=jQuery('input[name=wppp_age]');
				}
			}
			if(jQuery('input[name=wppp_unit_of_measurement]:checked').length < 1) {
				errorMessage.push("Please select a unit of measurement");
				if( typeof(elFocus) == 'undefined' )
				{
					elFocus=jQuery('input[name=wppp_unit_of_measurement]');
				}
			}
			if(jQuery('input[name=wppp_weight]').val() === '' || (jQuery('input[name=wppp_weight]').val() !== '' && !floatCheck.test(jQuery('input[name=wppp_weight]').val()))){
				errorMessage.push("Please enter a proper value for your weight");
				if( typeof(elFocus) == 'undefined' )
				{
					elFocus=jQuery('input[name=wppp_weight]');
				}
			}
			if(jQuery('input[name=wppp_height]').val() === '' || (jQuery('input[name=wppp_height]').val() !== '' && !floatCheck.test(jQuery('input[name=wppp_height]').val()))){
				errorMessage.push("Please enter a proper value for your height");
				if( typeof(elFocus) == 'undefined' )
				{
					elFocus=jQuery('input[name=wppp_height]');
				}
			}
			if( errorMessage.length > 0 )
			{
				if(jQuery('#wppp-validation').length > 0) {
					jQuery('#wppp-validation').remove();
				}
				var errorBlockquote = jQuery('<blockquote/>').attr('style','color:#ff0000');
				var errorList = errorMessage.join('<br/>');
				jQuery(errorBlockquote).append(errorList);
				var errorP = jQuery('<p/>').html('<strong>Unable to process</strong><br/>').append(errorBlockquote);
				var errorDiv = jQuery('<div/>').attr('id','wppp-validation').addClass('updated fade').append(errorP);
				jQuery('#wppp_form').before(errorDiv);			
				elFocus.focus();
				return false;
			}
			else
			{
				sex = jQuery('input[name=wppp_sex]:checked').val();
				age = jQuery('input[name=wppp_age]').val();
				unit = jQuery('input[name=wppp_unit_of_measurement]:checked').val();
				weight = jQuery('input[name=wppp_weight]').val();
				height = jQuery('input[name=wppp_height]').val();
				if(unit == 'english') {
					weight = weight / 2.20462262;
					height = height * .0254;
				}
				if(sex == 'male') {
					tee = 864 - (9.72*age) + 1.12 * (14.2*weight+503*height);
				}
				else {
					tee = 387 - (7.31*age) + 1.14 * (10.9*weight+660.7*height);
				}
				atee = 0.9 * tee + 200;
				targetPoints = Math.min( Math.max( Math.round( (Math.max( atee-1000, 1000) ) / 35) -11, 29), 71);
				//targetPoints = Math.min(Math.max((Math.Round(Math.max(atee-1000, 1000)/35)-11),29),71);
				jQuery('input[name=wppp_daily_points]').val(targetPoints);
				jQuery('#wppp_form').submit();
			}
		});
		return false;
	});
	</script>
	<form method="post" id="wppp_form" action="options.php">
	<?php settings_fields( 'wppp-settings-group' ); ?>
		<!-- <p><em>All fields are required</em></p> -->
		<dl class="clearfix">
			<dt><label for="male">Sex<em>*</em></label></dt>
			<dd>
				<input type="radio" id="male" name="wppp_sex" value="male"<?php if(get_option('wppp_sex') && get_option('wppp_sex') == "male") { ?> checked="checked"<?php } ?> /> <label for="male">Male</label> 
				<input type="radio" id="female" name="wppp_sex" value="female"<?php if(get_option('wppp_sex') && get_option('wppp_sex') == "female"){ ?> checked="checked" /><?php } ?> <label for="female">Female</label>
			</dd>
			
			<dt><label for="wppp_age">Age<em>*</em></label></dt> 
			<dd><input type="text" id="wppp_age" name="wppp_age" value="<?php echo get_option('wppp_age'); ?>" /></dd>
		
			<dt><label for="english">Unit of Measure<em>*</em></label></dt>
			<dd>
				<input type="radio" id="metric" name="wppp_unit_of_measurement" value="metric"<?php if(get_option('wppp_unit_of_measurement') && get_option('wppp_unit_of_measurement') == "metric") { ?> checked="checked"<?php } ?> /> <label for="metric">Metric (kilograms &amp; meters)</label> 
				<input type="radio" id="english" name="wppp_unit_of_measurement" value="english"<?php if(get_option('wppp_unit_of_measurement') && get_option('wppp_unit_of_measurement') == "english"){ ?> checked="checked"<?php } ?> /> <label for="english">English (pounds &amp; inches)</label>
			</dd>

			<dt><label for="wppp_weight">Weight<em>*</em></label></dt> 
			<dd><input type="text" id="wppp_weight" name="wppp_weight" value="<?php echo get_option('wppp_weight'); ?>" /><span></span></dd>
			
			<dt><label for="wppp_height">Height<em>*</em></label></dt>
			<dd><input type="text" id="wppp_height" name="wppp_height" value="<?php echo get_option('wppp_height'); ?>" /><span></span></dd>
			
			<dt></dt>
			<dd><input type="hidden" name="wppp_daily_points" value="<?php echo get_option('wppp_daily_points'); ?>" /><span>Daily Plus Points = <strong><?php echo get_option('wppp_daily_points'); ?></strong></span></dd>

			<dt></dt>
			<dd><input type="checkbox" id="show" name="wppp_credits" value="true"<?php if(!get_option('wppp_daily_points') || get_option('wppp_credits') == "true") { ?> checked="checked"<?php } ?> /> <label for="show">Show Plug-in Credits</label></dd>

			<dt></dt>
			<dd><input type="submit" class="button-primary" value="<?php _e('Save Changes', 'wp_pluspoints') ?>" /> <input type="reset" class="button-secondary" value="Clear Form" /></dd>
		</dl>
		<div id="wppp_logo"></div>
	</form>
	<div style="font-size:x-small;">
		<p><strong style="color:#cc0000;">IMPORTANT:</strong> This is not affiliated with Weight Watchers&reg; nor is it a Weight Watchers&reg; product. The Official Points Plus calculators and program information can be found at the <a href="http:/www.weightwatchers.com/" title=Weight Watchers" target="_blank">Weight Watchers&reg;</a> web site.<br/>
		<em style="font-size:xx-small;">Please note that Weight Watchers Points Plus and Points are registered trademarks of Weight Watchers Inc.</em></p>
	</div>
	<h3>Using the plug-in</h3>
	<div id="wppp-tutorial" class="updated fade"><p><strong>NOTE:</strong> Please <a href="" title="How to use WordPress Plus Points plug-in">watch our video tutorial</a> that explains how to use the plug-in on your WordPress site.</p></div>
	<div>
		<p>This plug-in currently makes the following assumptions.</p>
		<ol>
			<li>Posts will not log more then one day of data.</li>
			<li>Pages will not log more then one day of data.</li>
			<li>There is only one user per site.</li>
		</ol>
	</div>
	<h3>Using the Shortcode API</h3>
	<div>		
		<p>The points can be inserted into your blog post by using WordPress 'shortcode' API. The current shortcode tags are [wppp] and [wppp_total]</p>
	</div>
	<h4>[wppp]</h4>
	<div>
		<p>The 'wppp' shortcode supports five different attributes. Those attributes, their default values and descriptions are:</p>
		<ul>
			<li>servings [default = 1]: How many servings consumed.</li>
			<li>protein [default = 0]: How much protein per serving (grams).</li>
			<li>carbs [default = 0]: How much carbohydrates per serving (grams).</li>
			<li>fat [default = 0]: How much fat per serving (grams).</li>
			<li>fiber [default = 0]: How much fiber per serving (grams).</li>
		</ul>
		<p><strong>Example:</strong> You have two servings of salsa that has 0g protein, 2g carbohydrates, 0g fat and 0g fiber. You can enter that shortcode in as follows.</p>
		<pre>[wppp servings=2 carbs=2]</pre>
		<p>Because all other values are the same as the default values you don't need to enter them.</p>
	</div>
	<h4>[wppp_total]</h4>
	<div>
		<p>The 'wppp_total' shortcode will display the total values in the post and compares them to the daily points target. This shortcode does not have any attributes passed to it.</p>
		<pre>[wppp_total]</pre>
	</div>
	<h3>Embedding into Theme</h3>
	<div>
		<p><strong>NOTE:</strong> This is not the preferred method. Because this method embeds the function call into your template, this could cause errors if the template is deactivated.</p>
		<p>You can embed the plug-in into your theme by simply inserting the following call into your theme</p>
		<p><strong>wppp</strong></p>
		<pre>&lt;?php echo wp_pluspoints_func(); ?&gt;</pre>
		<p><strong>wppp_total</strong></p>
		<pre>&lt;?php echo wp_pluspoints_total_func(); ?&gt;</pre>
	</div>
	<div>
		<p>Learn more about this plug-in at <a href="http://www.dingobytes.com/" title="Dingobytes.com">http://www.dingobytes.com/</a>.</p>
	</div>
</div>
<?php } ?>